================
L2Awinddirection
================


.. image:: https://img.shields.io/pypi/v/l2awinddirection.svg
        :target: https://pypi.python.org/pypi/l2awinddirection

.. image:: https://img.shields.io/travis/agrouaze/l2awinddirection.svg
        :target: https://travis-ci.com/agrouaze/l2awinddirection

.. image:: https://readthedocs.org/projects/l2awinddirection/badge/?version=latest
        :target: https://l2awinddirection.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Python package to generate Level-2A wind direction files from Sentinel-1 TOPS product based on low frequency texture analysis.


* Free software: MIT license
* Documentation: https://l2awinddirection.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
